CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
99 lines
3.1 KiB
C++
99 lines
3.1 KiB
C++
// Copyright (C) 2023-2026 Advanced Micro Devices, Inc. All rights reserved.
|
|
//
|
|
// Permission is hereby granted, free of charge, to any person obtaining a copy
|
|
// of this software and associated documentation files (the "Software"), to deal
|
|
// in the Software without restriction, including without limitation the rights
|
|
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
|
// copies of the Software, and to permit persons to whom the Software is
|
|
// furnished to do so, subject to the following conditions:
|
|
//
|
|
// The above copyright notice and this permission notice shall be included in
|
|
// all copies or substantial portions of the Software.
|
|
//
|
|
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
|
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
|
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
|
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
|
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
|
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
|
// THE SOFTWARE.
|
|
|
|
#ifndef __ROCFFT_HIP_H__
|
|
#define __ROCFFT_HIP_H__
|
|
|
|
#include <atomic>
|
|
#include <cstddef>
|
|
#include <hip/hip_runtime_api.h>
|
|
#include <stdexcept>
|
|
#include <string>
|
|
|
|
// exception for hip runtime error(s) specifically
|
|
struct hip_runtime_error : public std::runtime_error
|
|
{
|
|
const hipError_t hip_error;
|
|
hip_runtime_error(const std::string& info, hipError_t hip_status)
|
|
: std::runtime_error::runtime_error(info)
|
|
, hip_error(hip_status)
|
|
{
|
|
n_hip_failures++;
|
|
}
|
|
|
|
static inline size_t get_count()
|
|
{
|
|
return n_hip_failures;
|
|
}
|
|
|
|
private:
|
|
static inline std::atomic<size_t> n_hip_failures = 0;
|
|
};
|
|
|
|
class rocfft_scoped_device
|
|
{
|
|
public:
|
|
static int device_count()
|
|
{
|
|
static int count = 0;
|
|
if(count == 0)
|
|
{
|
|
const auto ret = hipGetDeviceCount(&count);
|
|
if(ret != hipSuccess)
|
|
throw hip_runtime_error("failed to get device count", ret);
|
|
}
|
|
return count;
|
|
}
|
|
|
|
static int current_device()
|
|
{
|
|
int currentDevice = hipInvalidDeviceId;
|
|
const auto ret = hipGetDevice(¤tDevice);
|
|
if(ret != hipSuccess)
|
|
throw hip_runtime_error("failed to get HIP device", ret);
|
|
return currentDevice;
|
|
}
|
|
|
|
rocfft_scoped_device(int device)
|
|
{
|
|
auto ret = hipGetDevice(&orig_device);
|
|
if(ret != hipSuccess)
|
|
throw hip_runtime_error("hipGetDevice failure", ret);
|
|
|
|
ret = hipSetDevice(device);
|
|
if(ret != hipSuccess)
|
|
throw hip_runtime_error("hipSetDevice failure", ret);
|
|
}
|
|
~rocfft_scoped_device()
|
|
{
|
|
(void)hipSetDevice(orig_device);
|
|
}
|
|
|
|
// not copyable or movable
|
|
rocfft_scoped_device(const rocfft_scoped_device&) = delete;
|
|
rocfft_scoped_device(rocfft_scoped_device&&) = delete;
|
|
rocfft_scoped_device& operator=(const rocfft_scoped_device&) = delete;
|
|
|
|
private:
|
|
int orig_device;
|
|
};
|
|
|
|
#endif // __ROCFFT_HIP_H__
|